@@ -2,8 +2,10 @@ package Apache::Session::Browseable::Store::Redis;
 
 use strict;
 
-our $VERSION = '1.3.15';
+our $VERSION = '1.3.18';
+
 our $redis;
+our %reused_connections;
 
 BEGIN {
     $redis = 'Redis::Fast';
@@ -18,25 +20,7 @@ sub new {
     my ( $class, $session ) = @_;
     my $self;
 
-    # Manage undef encoding
-    $session->{args}->{encoding} = undef
-      if (  $session->{args}->{encoding}
-        and $session->{args}->{encoding} eq "undef" );
-
-    # If sentinels is not given as an array ref, try to parse
-    # a comma delimited list instead
-    if ( $session->{args}->{sentinels}
-        and ref $session->{args}->{sentinels} ne 'ARRAY' )
-    {
-        $session->{args}->{sentinels} =
-          [ split /[,\s]+/, $session->{args}->{sentinels} ];
-    }
-
-    $self->{cache} = $redis->new( %{ $session->{args} } );
-
-    # Manage database
-    $self->{cache}->select( $session->{args}->{database} )
-      if defined $session->{args}->{database};
+    $self->{cache} = $class->_getRedis( $session->{args} );
 
     bless $self, $class;
 }
@@ -82,6 +66,43 @@ sub remove {
     $self->{cache}->del($id);
 }
 
+sub _getRedis {
+    my $class = shift;
+    my $args  = shift;
+    my $redisObj;
+
+    # Manage undef encoding
+    $args->{encoding} = undef
+      if (  $args->{encoding}
+        and $args->{encoding} eq "undef" );
+
+    # If sentinels is not given as an array ref, try to parse
+    # a comma delimited list instead
+    if ( $args->{sentinels}
+        and ref $args->{sentinels} ne 'ARRAY' )
+    {
+        $args->{sentinels} =
+          [ split /[,\s]+/, $args->{sentinels} ];
+    }
+
+    if (    $args->{reuse}
+        and $reused_connections{ $args->{reuse} } )
+    {
+        $redisObj = $reused_connections{ $args->{reuse} };
+    }
+    else {
+        $redisObj = $redis->new( %{$args} );
+        if ( $args->{reuse} ) {
+            $reused_connections{ $args->{reuse} } = $redisObj;
+        }
+    }
+
+    # Manage database
+    $redisObj->select( $args->{database} )
+      if defined $args->{database};
+    return $redisObj;
+}
+
 1;
 __END__
 
